==> openflowplugin-extension-nicira-0.7.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/conntrack/grouping/NxConntrack.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Short;
import java.util.List;
import javax.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionConntrackGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping.nx.conntrack.CtActions;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-conntrack {
 *   leaf flags {
 *     type uint16;
 *   }
 *   leaf zone-src {
 *     type uint32;
 *   }
 *   leaf conntrack-zone {
 *     type uint16;
 *   }
 *   leaf recirc-table {
 *     type uint8;
 *   }
 *   list ct-actions {
 *     uses ofpact-actions;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-conntrack-grouping/nx-conntrack</i>
 *
 * <p>To create instances of this class use {@link NxConntrackBuilder}.
 * @see NxConntrackBuilder
 *
 */
public interface NxConntrack
    extends
    ChildOf<NxActionConntrackGrouping>,
    Augmentable<NxConntrack>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-conntrack");

    /**
     * @return <code>java.lang.Integer</code> <code>flags</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getFlags();
    
    /**
     * @return <code>java.lang.Long</code> <code>zoneSrc</code>, or <code>null</code> if not present
     */
    @Nullable
    Long getZoneSrc();
    
    /**
     * @return <code>java.lang.Integer</code> <code>conntrackZone</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getConntrackZone();
    
    /**
     * @return <code>java.lang.Short</code> <code>recircTable</code>, or <code>null</code> if not present
     */
    @Nullable
    Short getRecircTable();
    
    /**
     * @return <code>java.util.List</code> <code>ctActions</code>, or <code>null</code> if not present
     */
    @Nullable
    List<CtActions> getCtActions();

}

==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/conntrack/grouping/NxConntrack.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Short;
import java.util.List;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionConntrackGrouping;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping.nx.conntrack.CtActions;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-conntrack {
 *   leaf flags {
 *     type uint16;
 *   }
 *   leaf zone-src {
 *     type uint32;
 *   }
 *   leaf conntrack-zone {
 *     type uint16;
 *   }
 *   leaf recirc-table {
 *     type uint8;
 *   }
 *   list ct-actions {
 *     uses ofpact-actions;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-conntrack-grouping/nx-conntrack</i>
 *
 * <p>To create instances of this class use {@link NxConntrackBuilder}.
 * @see NxConntrackBuilder
 *
 */
public interface NxConntrack
    extends
    ChildOf<NxActionConntrackGrouping>,
    Augmentable<NxConntrack>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-conntrack");

    /**
     * @return <code>java.lang.Integer</code> <code>flags</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlags();
    
    /**
     * @return <code>java.lang.Long</code> <code>zoneSrc</code>, or <code>null</code> if not present
     */
    @Nullable Long getZoneSrc();
    
    /**
     * @return <code>java.lang.Integer</code> <code>conntrackZone</code>, or <code>null</code> if not present
     */
    @Nullable Integer getConntrackZone();
    
    /**
     * @return <code>java.lang.Short</code> <code>recircTable</code>, or <code>null</code> if not present
     */
    @Nullable Short getRecircTable();
    
    /**
     * @return <code>java.util.List</code> <code>ctActions</code>, or <code>null</code> if not present
     */
    @Nullable List<CtActions> getCtActions();
    
    /**
     * @return <code>java.util.List</code> <code>ctActions</code>, or an empty list if it is not present
     */
    default @NonNull List<CtActions> nonnullCtActions() {
        return CodeHelpers.nonnull(getCtActions());
    }

}
